@@ -354,7 +354,108 @@ class TestExposeDCMetaTags(PloneTestCase.FunctionalTestCase):
         self.assert_(m, 'DC meta tags not avaliable when createManager=True')
 
 
-TESTS = [TestInstallation, TestResponse, TestExposeDCMetaTags]
+class TestMetaTagsDuplication(PloneTestCase.FunctionalTestCase):
+
+    def afterSetUp(self):
+        self.qi = self.portal.portal_quickinstaller
+        self.basic_auth = 'portal_manager:secret'
+        uf = self.app.acl_users
+        uf.userFolderAddUser('portal_manager', 'secret', ['Manager'], [])
+        user = uf.getUserById('portal_manager')
+        if not hasattr(user, 'aq_base'):
+            user = user.__of__(uf)
+        newSecurityManager(None, user)
+
+        '''Preparation for functional testing'''
+        self.my_doc = self.portal.invokeFactory('Document', id='my_doc')
+        self.my_doc = self.portal['my_doc']
+        self.my_doc.update(description="Document description")
+
+    def test_GeneratorMeta(self):
+        # Get document without customized canonical url
+        abs_path = "/%s" % self.my_doc.absolute_url(1)
+        regen = re.compile('<meta\s+[^>]*name=\"generator\"[^>]*>', re.S|re.M)
+
+        # Before product installation
+        html = self.publish(abs_path, self.basic_auth).getBody()
+        lengen = len(regen.findall(html))
+        self.assert_(lengen==1, "There is %d generator meta tag(s) " \
+           "before seoptimizer installation" % lengen)
+
+#         # After PRODUCT installation
+#         self.qi.installProduct(PRODUCT)
+#         html = self.publish(abs_path, self.basic_auth).getBody()
+#         lengen = len(regen.findall(html))
+#         self.assert_(lengen==1, "There is %d generator meta tag(s) " \
+#            "after seoptimizer installation" % lengen)
+
+    def test_DescriptionMeta(self):
+        # Get document without customized canonical url
+        abs_path = "/%s" % self.my_doc.absolute_url(1)
+        regen = re.compile('<meta\s+[^>]*name=\"description\"[^>]*>', re.S|re.M)
+
+        # Before product installation
+        html = self.publish(abs_path, self.basic_auth).getBody()
+        lendesc = len(regen.findall(html))
+        self.assert_(lendesc==1, "There is %d DESCRIPTION meta tag(s) " \
+           "before seoptimizer installation" % lendesc)
+
+#         # After PRODUCT installation
+#         self.qi.installProduct(PRODUCT)
+#         html = self.publish(abs_path, self.basic_auth).getBody()
+#         lendesc = len(regen.findall(html))
+#         self.assert_(lendesc==1, "There is %d DESCRIPTION meta tag(s) " \
+#            "after seoptimizer installation" % lendesc)
+
+class TestBaseURL(PloneTestCase.FunctionalTestCase):
+
+    def afterSetUp(self):
+        self.qi = self.portal.portal_quickinstaller
+        self.qi.installProduct(PRODUCT)
+        #self.portal.changeSkin('Plone Default')
+
+        self.basic_auth = 'portal_manager:secret'
+        uf = self.app.acl_users
+        uf.userFolderAddUser('portal_manager', 'secret', ['Manager'], [])
+        user = uf.getUserById('portal_manager')
+        if not hasattr(user, 'aq_base'):
+            user = user.__of__(uf)
+        newSecurityManager(None, user)
+
+    def test_notFolderBaseURL(self):
+        my_doc = self.portal.invokeFactory('Document', id='my_doc')
+        my_doc = self.portal['my_doc']
+        regen = re.compile('<base\s+[^>]*href=\"([^\"]*)\"[^>]*>', re.S|re.M)
+        
+        path = "/%s" % my_doc.absolute_url(1)
+        html = self.publish(path, self.basic_auth).getBody()
+        burls = regen.findall(html)
+        
+        mydocurl = my_doc.absolute_url()
+        self.assert_(not [1 for burl in burls if not burl==mydocurl],
+           "Wrong BASE URL for document: %s, all must be: %s" % (burls, mydocurl))
+
+    def test_folderBaseURL(self):
+        my_fldr = self.portal.invokeFactory('Folder', id='my_fldr')
+        my_fldr = self.portal['my_fldr']
+        regen = re.compile('<base\s+[^>]*href=\"([^\"]*)\"[^>]*>', re.S|re.M)
+        
+        path = "/%s" % my_fldr.absolute_url(1)
+        html = self.publish(path, self.basic_auth).getBody()
+        burls = regen.findall(html)
+
+        myfldrurl = my_fldr.absolute_url() + '/'
+        self.assert_(not [1 for burl in burls if not burl==myfldrurl],
+           "Wrong BASE URL for folder: %s , all must be : %s" % (burls, myfldrurl))
+
+TESTS = [TestBeforeInstall,
+         TestInstallation,
+         TestResponse,
+         TestExposeDCMetaTags,
+         TestAdditionalKeywords,
+         TestMetaTagsDuplication,
+         TestBaseURL,
+        ]
 
 def test_suite():
     from unittest import TestSuite, makeSuite
@@ -362,9 +463,6 @@ def test_suite():
     for suite_class in TESTS:
         suite.addTest(makeSuite(suite_class))
 
-    suite.addTest(makeSuite(TestBeforeInstall))
-    suite.addTest(makeSuite(TestAdditionalKeywords))
-
     return suite
 
 if __name__ == '__main__':
